==> jc-1.4.0.tar.gz: java/awt/event/HierarchyBoundsAdapter.h <==
// public abstract class java.awt.event.HierarchyBoundsAdapter

// class file dependencies
// @dep_class ba26f717df7cea71 java_awt_event_HierarchyBoundsAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_event_HierarchyBoundsAdapter_H_
#define _JC_java_awt_event_HierarchyBoundsAdapter_H_

// Forward structure declarations
struct _jc_java_awt_event_HierarchyEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_event_HierarchyBoundsAdapter$sub_refs	_jc_java_awt_event_HierarchyBoundsAdapter$sub_refs;
typedef struct _jc_java_awt_event_HierarchyBoundsAdapter$sub_nonrefs	_jc_java_awt_event_HierarchyBoundsAdapter$sub_nonrefs;
typedef struct _jc_java_awt_event_HierarchyBoundsAdapter$refs	_jc_java_awt_event_HierarchyBoundsAdapter$refs;
typedef struct _jc_java_awt_event_HierarchyBoundsAdapter$nonrefs	_jc_java_awt_event_HierarchyBoundsAdapter$nonrefs;
typedef struct _jc_java_awt_event_HierarchyBoundsAdapter$object	_jc_java_awt_event_HierarchyBoundsAdapter$object;

typedef const struct _jc_java_awt_event_HierarchyBoundsAdapter$vmethods	_jc_java_awt_event_HierarchyBoundsAdapter$vmethods;
typedef const struct _jc_java_awt_event_HierarchyBoundsAdapter$vtable	_jc_java_awt_event_HierarchyBoundsAdapter$vtable;
typedef const struct _jc_java_awt_event_HierarchyBoundsAdapter$vtype	_jc_java_awt_event_HierarchyBoundsAdapter$vtype;

// Constructors
extern void _jc_java_awt_event_HierarchyBoundsAdapter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_event_HierarchyBoundsAdapter$object *);

// Virtual methods
extern void _jc_java_awt_event_HierarchyBoundsAdapter$method$ancestorMoved$05a7fb3aa22f701f(_jc_env *, struct _jc_java_awt_event_HierarchyBoundsAdapter$object *, struct _jc_java_awt_event_HierarchyEvent$object *);
extern void _jc_java_awt_event_HierarchyBoundsAdapter$method$ancestorResized$a396204358a57ba6(_jc_env *, struct _jc_java_awt_event_HierarchyBoundsAdapter$object *, struct _jc_java_awt_event_HierarchyEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_HierarchyBoundsAdapter$method_info$ancestorMoved$05a7fb3aa22f701f;
extern _jc_method _jc_java_awt_event_HierarchyBoundsAdapter$method_info$ancestorResized$a396204358a57ba6;

// Virtual methods structure
struct _jc_java_awt_event_HierarchyBoundsAdapter$vmethods {
	void	(*ancestorMoved$05a7fb3aa22f701f)(_jc_env *, struct _jc_java_awt_event_HierarchyBoundsAdapter$object *, struct _jc_java_awt_event_HierarchyEvent$object *);
	void	(*ancestorResized$a396204358a57ba6)(_jc_env *, struct _jc_java_awt_event_HierarchyBoundsAdapter$object *, struct _jc_java_awt_event_HierarchyEvent$object *);
};

// Vtable
struct _jc_java_awt_event_HierarchyBoundsAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_HierarchyBoundsAdapter$vmethods	java_awt_event_HierarchyBoundsAdapter;
};

// Vtype
struct _jc_java_awt_event_HierarchyBoundsAdapter$vtype {
	_jc_type			type;
	_jc_java_awt_event_HierarchyBoundsAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_HierarchyBoundsAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_HierarchyBoundsAdapter$refs {
    _jc_java_awt_event_HierarchyBoundsAdapter$sub_refs	java_awt_event_HierarchyBoundsAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_HierarchyBoundsAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_HierarchyBoundsAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_HierarchyBoundsAdapter$sub_nonrefs	java_awt_event_HierarchyBoundsAdapter;
};

// Object instance structure
struct _jc_java_awt_event_HierarchyBoundsAdapter$object {
	_jc_java_awt_event_HierarchyBoundsAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_HierarchyBoundsAdapter$vtype	*vtype;
	_jc_java_awt_event_HierarchyBoundsAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_HierarchyBoundsAdapter$vtype _jc_java_awt_event_HierarchyBoundsAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_HierarchyBoundsAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_HierarchyBoundsAdapter$class_object;

#endif	/* _JC_java_awt_event_HierarchyBoundsAdapter_H_ */

==> jc-1.4.6.tar.gz: java/awt/event/HierarchyBoundsAdapter.h <==
// public abstract class java.awt.event.HierarchyBoundsAdapter

// class file dependencies
// @dep_class ba26f717df7cea71 java_awt_event_HierarchyBoundsAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_event_HierarchyBoundsAdapter_H_
#define _JC_java_awt_event_HierarchyBoundsAdapter_H_

// Forward structure declarations
struct _jc_java_awt_event_HierarchyEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_event_HierarchyBoundsAdapter$sub_refs	_jc_java_awt_event_HierarchyBoundsAdapter$sub_refs;
typedef struct _jc_java_awt_event_HierarchyBoundsAdapter$sub_nonrefs	_jc_java_awt_event_HierarchyBoundsAdapter$sub_nonrefs;
typedef struct _jc_java_awt_event_HierarchyBoundsAdapter$refs	_jc_java_awt_event_HierarchyBoundsAdapter$refs;
typedef struct _jc_java_awt_event_HierarchyBoundsAdapter$nonrefs	_jc_java_awt_event_HierarchyBoundsAdapter$nonrefs;
typedef struct _jc_java_awt_event_HierarchyBoundsAdapter$object	_jc_java_awt_event_HierarchyBoundsAdapter$object;

typedef const struct _jc_java_awt_event_HierarchyBoundsAdapter$vmethods	_jc_java_awt_event_HierarchyBoundsAdapter$vmethods;
typedef const struct _jc_java_awt_event_HierarchyBoundsAdapter$vtable	_jc_java_awt_event_HierarchyBoundsAdapter$vtable;
typedef const struct _jc_java_awt_event_HierarchyBoundsAdapter$vtype	_jc_java_awt_event_HierarchyBoundsAdapter$vtype;

// Constructors
extern void _jc_java_awt_event_HierarchyBoundsAdapter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_event_HierarchyBoundsAdapter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_event_HierarchyBoundsAdapter$method$ancestorMoved$05a7fb3aa22f701f(_jc_env *, struct _jc_java_awt_event_HierarchyBoundsAdapter$object *, struct _jc_java_awt_event_HierarchyEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_HierarchyBoundsAdapter$method$ancestorResized$a396204358a57ba6(_jc_env *, struct _jc_java_awt_event_HierarchyBoundsAdapter$object *, struct _jc_java_awt_event_HierarchyEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_HierarchyBoundsAdapter$method_info$ancestorMoved$05a7fb3aa22f701f;
extern _jc_method _jc_java_awt_event_HierarchyBoundsAdapter$method_info$ancestorResized$a396204358a57ba6;

// Virtual methods structure
struct _jc_java_awt_event_HierarchyBoundsAdapter$vmethods {
	void	(*ancestorMoved$05a7fb3aa22f701f)(_jc_env *, struct _jc_java_awt_event_HierarchyBoundsAdapter$object *, struct _jc_java_awt_event_HierarchyEvent$object *) _JC_JCNI_ATTR;
	void	(*ancestorResized$a396204358a57ba6)(_jc_env *, struct _jc_java_awt_event_HierarchyBoundsAdapter$object *, struct _jc_java_awt_event_HierarchyEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_HierarchyBoundsAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_HierarchyBoundsAdapter$vmethods	java_awt_event_HierarchyBoundsAdapter;
};

// Vtype
struct _jc_java_awt_event_HierarchyBoundsAdapter$vtype {
	_jc_type			type;
	_jc_java_awt_event_HierarchyBoundsAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_HierarchyBoundsAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_HierarchyBoundsAdapter$refs {
    _jc_java_awt_event_HierarchyBoundsAdapter$sub_refs	java_awt_event_HierarchyBoundsAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_HierarchyBoundsAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_HierarchyBoundsAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_HierarchyBoundsAdapter$sub_nonrefs	java_awt_event_HierarchyBoundsAdapter;
};

// Object instance structure
struct _jc_java_awt_event_HierarchyBoundsAdapter$object {
	_jc_java_awt_event_HierarchyBoundsAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_HierarchyBoundsAdapter$vtype	*vtype;
	_jc_java_awt_event_HierarchyBoundsAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_HierarchyBoundsAdapter$vtype _jc_java_awt_event_HierarchyBoundsAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_HierarchyBoundsAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_HierarchyBoundsAdapter$class_object;

#endif	/* _JC_java_awt_event_HierarchyBoundsAdapter_H_ */
